@@ -14,7 +14,7 @@
 #' \donttest{get_tournaments()}
 #'
 #' ## Get data on 2020 non-PSA World Tour tournaments
-#' \donttest{get_tournaments(2020, world_tour = FALSE)}
+#' \donttest{get_tournaments(2021, world_tour = FALSE)}
 #'
 #' @note This function only returns tournaments from 2020 and 2021, as any other data are not available to non-premium members on SquashInfo.
 #'
@@ -59,7 +59,7 @@ get_tournaments <- function(year = 2021, world_tour = TRUE) {
   t_url <- "http://www.squashinfo.com/results?start=1"
 
   # Empty tournaments object
-  tournaments <- c()
+  tournaments <- NULL
 
   # Set arbitrary variable to test for tournament result limit
   results_limit <- 0
@@ -179,11 +179,11 @@ get_tournaments <- function(year = 2021, world_tour = TRUE) {
 #' @return Tibble containing the tournament name, competition category, tournament date, player, seed, nationality, round_reached.
 #'
 #' @examples
-#' ## Who played in the Black Ball Open in 2020?
-#' \donttest{get_tournament_players(tournament = "Black Ball Open", year = 2020)}
+#' ## Who played in the Black Ball Open in 2021?
+#' \donttest{get_tournament_players(tournament = "Black Ball Open", year = 2021)}
 #'
-#' ## Return player registrant data for all PSA World Tour tournaments in 2020
-#' \donttest{get_tournament_players(year = 2020, world_tour = TRUE)}
+#' ## Return player registrant data for all PSA World Tour tournaments in 2021
+#' \donttest{get_tournament_players(year = 2021, world_tour = TRUE)}
 #'
 #' @note This function only returns player registrant data from tournaments in 2020 and 2021, as any other data are not available to non-premium members on SquashInfo. Additionally, events that do not use a single elimination format are not included in the results (e.g. Karakal Premier League).
 #'
@@ -222,11 +222,11 @@ get_tournament_players <- function(tournament = NULL, year = 2021, world_tour =
 #' @return Tibble containing the tournament name, competition category, tournament date, round, player 1, player 2, the match winner, games won (by player 1), games lost (by player 1), the match time, player 1's seed, player 2's seed, player 1's nationality, player 2's nationality.
 #'
 #' @examples
-#' ## Return match data for 2020's Black Ball Open.
-#' \donttest{get_tournament_matches("Black Ball Open", year = 2020, world_tour = TRUE)}
+#' ## Return match data for 2021's Black Ball Open.
+#' \donttest{get_tournament_matches("Black Ball Open", year = 2021, world_tour = TRUE)}
 #'
-#' ## Return match data for all PSA World Tour tournaments in 2020
-#' \donttest{get_tournament_matches(year = 2020, world_tour = TRUE)}
+#' ## Return match data for all PSA World Tour tournaments in 2021
+#' \donttest{get_tournament_matches(year = 2021, world_tour = TRUE)}
 #'
 #'
 #'
@@ -361,11 +361,11 @@ get_tournament_matches <- function(tournament = NULL, year = NULL, world_tour =
 #' @return Tibble containing the tournament name, competition category, tournament date, round, match number, game number, player 1, player 2, the game winner, player 1's score, player 2's score, player 1's seed, player 2's seed, player 1's nationality, player 2's nationality.
 #'
 #' @examples
-#' ## Return game data for 2020's Black Ball Open.
-#' \donttest{get_tournament_games("Black Ball Open", year = 2020, world_tour = TRUE)}
+#' ## Return game data for 2021's Black Ball Open.
+#' \donttest{get_tournament_games("Black Ball Open", year = 2021, world_tour = TRUE)}
 #'
-#' ## Return game data for all PSA World Tour tournaments in 2020
-#' \donttest{get_tournament_games(year = 2020, world_tour = TRUE)}
+#' ## Return game data for all PSA World Tour tournaments in 2021
+#' \donttest{get_tournament_games(year = 2021, world_tour = TRUE)}
 #'
 #'
 #' @note This function only returns game data from tournaments in 2020 and 2021, as any other data are not available to non-premium members on SquashInfo. Additionally, events that do not use a single elimination format are not included in the results (e.g. Karakal Premier League).
@@ -451,7 +451,7 @@ get_tournament_ <- function(tournament = NULL, year = NULL, world_tour = NULL) {
   t_url <- "http://www.squashinfo.com/results?start=1"
 
   # Empty tournaments object
-  tournaments <- c()
+  tournaments <- NULL
 
   # Set arbitrary variable to test for tournament result limit
   results_limit <- 0
@@ -648,7 +648,7 @@ get_tournament_objects <- function(tournaments = NULL, level = NULL) {
   }
 
   ## Create empty data frame
-  data <- c()
+  data <- NULL
 
   for (i in seq_along(tournaments$slug)) {
 
@@ -679,6 +679,7 @@ get_tournament_objects <- function(tournaments = NULL, level = NULL) {
 
     ## Find html tables
     result <- current_page %>%
+      html_nodes(xpath = '//*[@id="results"]') %>%
       html_nodes("table") %>%
       html_table() %>%
       as.data.frame()
@@ -805,7 +806,7 @@ get_tournament_objects <- function(tournaments = NULL, level = NULL) {
                               } else if (length(unique(result$round)) == 2) {
                                c("SF", "F")
                               } else if (length(unique(result$round)) == 1) {
-                               c("F")
+                               "F"
                               }, ordered = TRUE),
                             ## Add tournament name, category, date
                             tournament_name = t_name,
